translate.convert.convert

Package translate :: Package convert :: Module convert |
[hide private]
[frames] | no frames]

# Module convert

source code

Handles converting of files between formats (used by translate.convert tools)

Classes | [hide private]
| ConvertOptionParser a specialized Option Parser for convertor tools...
| Replacer an object that knows how to replace strings in files
| ArchiveConvertOptionParser ConvertOptionParser that can handle recursing into single archive files.

Functions | [hide private]
copyinput(inputfile, outputfile, templatefile, **kwargs) copies the input file to the output file | source code
copytemplate(inputfile, outputfile, templatefile, **kwargs) copies the template file to the output file | source code
main(argv=None) | source code

Imports: os, optrecurse, optparse, StringIO